Learn R Programming

explorase (version 1.36.0)

exp_showResults: Show analysis results

Description

Add a column of analysis results to the exploRase table and the GGobi dataset.

Usage

exp_showResults(results, label, sublabels = "", types = exp_entityType(), keyword = NULL, explorase = T, ggobi = T)

Arguments

results
the data frame of results. To include results for multiple entity types at once, the result for each type should be concatenated in the same order as the types parameter.
label
a root label for the result (like the type of analysis)
sublabels
other labels concatenated to the root (such as the conditions involved)
types
the entity type(s) of the data from which this result was derived.
keyword
a keyword identifying this result, for use in context-sensitive help
explorase
whether to show the result in the explorase table
ggobi
whether to add the result to the GGobi dataset