Rdocumentation
powered by
Learn R Programming
explorase (version 1.36.0)
exp_calcEuclideanDist: Calculate Euclidean distance
Description
Calculates Euclidean distance between
ent
and the other entities across the samples (columns) in the data frame
ent_data
Usage
exp_calcEuclideanDist(ent_data, ent)
Arguments
ent_data
a data frame of experimental data, according to exploRase conventions
ent
the id of an entity that is compared to the entities in
ent_data